==> honeybee-grasshopper-radiance-1.6.2.tar.gz: honeybee-grasshopper-radiance-1.6.2/honeybee_grasshopper_radiance/src/HB Daylight Factor.py <==
# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2020, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Run daylight factor for a single model.

    Args:
        _model: A Honeybee Model for which Daylight Factor will be simulated.
            Note that this model should have grids assigned to it in order
            to produce meaningfule results.
        sensor_count_: Data type [string]
            The maximum number of grid points per parallel execution.
            Default [200]
        radiance_parameters_: Data type [string]
            Text with the radiance parameters for ray tracing.
            Default [-ab 2]

    Returns:
        recipe: A simulation recipe that contains a simulation instructions and
            input arguments. Use the "HB Run Recipe" component to execute the
            recipe and get results.
"""

ghenv.Component.Name = 'HB Daylight Factor'
ghenv.Component.NickName = 'DaylightFactor'
ghenv.Component.Message = '1.1.1'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '3 :: Recipes'
ghenv.Component.AdditionalHelpFromDocStrings = '1'

import json
import os

try:
    from ladybug.futil import preparedir, nukedir
    from ladybug.config import folders as lb_folders
except ImportError as e:
    raise ImportError('\nFailed to import ladybug:\n\t{}'.format(e))

try:
    from honeybee.model import Model
    from honeybee.config import folders as hb_folders
except ImportError as e:
    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))

try:
    from honeybee_radiance.config import folders as rad_folders
except ImportError as e:
    raise ImportError('\nFailed to import honeybee_radiance:\n\t{}'.format(e))

try:
    from ladybug_rhino.grasshopper import all_required_inputs
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))

# check the installed Radiance and ensure it's from the right date
compatible_rad_date = (2020, 9, 3)
hb_url = 'https://github.com/ladybug-tools/lbt-grasshopper/wiki/1.4-Compatibility-Matrix'
rad_msg = 'Download and install the version of Radiance listed in the Ladybug ' \
    'Tools compatibility matrix\n{}'.format(hb_url)
assert rad_folders.radiance_path is not None, \
    'No Radiance installation was found on this machine.\n{}'.format(rad_msg)
assert rad_folders.radiance_version_date >= compatible_rad_date, \
    'The installed Radiance is not from {} or later.' \
    '\n{}'.format('/'.join(str(v) for v in compatible_rad_date), rad_msg)


class Workflow(object):
    """Workflow class that remains the same for every type of recipe."""

    def __init__(self, workflow_json):
        self._info = workflow_json

    @property
    def owner(self):
        """Get text for workflow owner."""
        return self._info['recipe']['owner']

    @property
    def name(self):
        """Get text for workflow name."""
        return self._info['recipe']['name']

    @property
    def tag(self):
        """Get text for workflow tag."""
        return self._info['recipe']['tag']

    @property
    def path(self):
        """Get text for the local path to the workflow's YAML recipe."""
        return self._info['recipe']['path']

    @property
    def default_simulation_path(self):
        """Get text for the default directory in which the simulation is run."""
        try:
            return self._info['recipe']['default-simulation-path']
        except KeyError:
            return None

    @property
    def simulation_id(self):
        """Get text for the default simulation ID to use."""
        try:
            return self._info['recipe']['simulation-id']
        except KeyError:
            return None

    @property
    def result_file_extension(self):
        """Get text for the result file extension."""
        try:
            return self._info['recipe']['result-file-extension']
        except KeyError:
            return None

    @property
    def inputs(self):
        """Get text for formatted inputs."""
        inputs = ['  {}: {}'.format(*p) for p in self._info['inputs'].items()]
        return '\n'.join(inputs)

    @property
    def inputs_dict(self):
        """Get a dictionary for the inputs."""
        return self._info['inputs']

    def write_inputs_json(self, simulation_folder=None, indent=4):
        """Write the inputs.json file that gets passed to queenbee luigi.
        
        Args:
            simulation_folder: The full path to where the inputs.json file
                will be written and where the simulation will be run. If None
                the default_simulation_path on this Wirkflow will be used.
            indent: The indent at which the JSON will be written (Default: 4).
        """
        sim_fold = simulation_folder if simulation_folder else self.default_simulation_path
        inputs = self._info['inputs'].copy()  # avoid editing the base dictionary
        process_inputs(inputs, sim_fold)
        # write the inputs dictionary into a file
        if not os.path.isdir(sim_fold):
            preparedir(sim_fold)
        file_path = os.path.join(sim_fold, '{}-inputs.json'.format(self.name))
        with open(file_path, 'w') as fp:
            json.dump(inputs, fp, indent=indent)
        return file_path

    @staticmethod
    def process_inputs(inputs, simulation_folder):
        """A method that can be overwritten to process inputs in write_inputs_json.

        Args:
            inputs: A dictionay with the inputs of the workflows as keys.
            simulation_folder: Path to the folder in which the workflow is executed.
        """
        pass

    def ToString(self):
        return '%s:\n%s' % (self.name, self.inputs)


if all_required_inputs(ghenv.Component):
    # this part involves some checks that should be eventually integrated to Queenbee
    assert isinstance(_model, Model), \
        'Expected Honeybee Model. Got {}.'.format(type(_model))
    if len(_model.properties.radiance.sensor_grids) == 0:
        msg = 'Input _model contains no sensor grids, which will result in a ' \
            'meaningless simulation.\nMake sure that you have assigned grids to ' \
            'the Model with the "HB Assign Grids and Views" component.'
        raise ValueError(msg)
        print(msg)


    # this part is an optional step for each recipe to process the model
    def default_simulation_path(self):
        return os.path.join(
            hb_folders.default_simulation_folder,
            self._info['inputs']['model'].identifier, 'Radiance')

    def process_inputs(inputs, folder):
        model_fold = os.path.join(folder, 'model')
        if os.path.isdir(model_fold):
            nukedir(model_fold, rmdir=True)  # delete the folder if it already exists
        model = inputs['model']
        model.to_hbjson('model.hbjson', folder)
        inputs['model'] = 'model.hbjson'

    Workflow.default_simulation_path = property(default_simulation_path)
    Workflow.process_inputs = staticmethod(process_inputs)

    recipe = {
        'owner': 'ladybug-tools',
        'name': 'daylight-factor',
        'tag': '9d5d49c529514f1cb3873657142233ff4cf947d52c0722875dc8cbda50c9239b',
        'default-simulation-path': None,
        'simulation-id': 'daylight_factor',
        'result-file-extension': 'res'
      }
    _inputs = {
        'model': _model,
        'sensor-count': sensor_count_,
        'radiance-parameters': radiance_parameters_
    }

    # this part will always stay the same for every recipe
    inputs = {}
    for key, val in _inputs.items():
        if bool(val):
            inputs[key] = val
    workflow_json ={
      "recipe": recipe,
      "inputs": inputs
    }
    recipe = Workflow(workflow_json)

==> honeybee-grasshopper-radiance-1.7.1.tar.gz: honeybee-grasshopper-radiance-1.7.1/honeybee_grasshopper_radiance/src/HB Daylight Factor.py <==
# Honeybee: A Plugin for Environmental Analysis (GPL)
# This file is part of Honeybee.
#
# Copyright (c) 2020, Ladybug Tools.
# You should have received a copy of the GNU General Public License
# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
# 
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>

"""
Run daylight factor for a single model.

    Args:
        _model: A Honeybee Model for which Daylight Factor will be simulated.
            Note that this model should have grids assigned to it in order
            to produce meaningfule results.
        sensor_count_: Integer for the maximum number of sensor grid points per
            parallel execution. (Default: 200).
        radiance_par_: Text for the radiance parameters to be used for ray
            tracing. (Default: -ab 2 -aa 0.1 -ad 2048 -ar 64).

    Returns:
        recipe: A simulation recipe that contains a simulation instructions and
            input arguments. Use the "HB Run Recipe" component to execute the
            recipe and get results.
"""

ghenv.Component.Name = 'HB Daylight Factor'
ghenv.Component.NickName = 'DaylightFactor'
ghenv.Component.Message = '1.1.3'
ghenv.Component.Category = 'HB-Radiance'
ghenv.Component.SubCategory = '3 :: Recipes'
ghenv.Component.AdditionalHelpFromDocStrings = '1'

import os

try:
    from honeybee.config import folders as hb_folders
    from honeybee.model import Model
except ImportError as e:
    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))

try:
    from lbt_recipes.recipe import Recipe
except ImportError as e:
    raise ImportError('\nFailed to import lbt_recipes:\n\t{}'.format(e))

try:
    from ladybug_rhino.grasshopper import all_required_inputs
except ImportError as e:
    raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))


if all_required_inputs(ghenv.Component):
    # create the recipe and set the input arguments
    recipe = Recipe('daylight_factor')
    recipe.input_value_by_name('model', _model)
    recipe.input_value_by_name('sensor-count', sensor_count_)
    recipe.input_value_by_name('radiance-parameters', radiance_par_)

    # set the default project folder based on the model name if available
    if isinstance(_model, Model):
        recipe.default_project_folder = os.path.join(
            hb_folders.default_simulation_folder, _model.identifier, 'Radiance')
